; Glass Effect Text V1.1 (11-2007) (c) Copyright
; Created by Scott Mosteller  
; Comments and questions directed to http://www.gimpchat.com
;
; Create Glass Effect Text
; 
; Simply enter the text and select the effect type. The scrip will generate 4 frames with the selected effect
; You can control various aspects of each effect by adjusting the effect tweak parameter and the scatter
; parameter.
; 
; Simply save the generated text as an animated .GIF and you're done.
;
; Selecting Raw Layer will display all raw layers only
; Clicking off animation will display a single frame, flattend to background.
;
;    This program is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
; Compatible with all Gimp Versions 2.x - Enjoy!
;
; ------------
;| Change Log |
; ------------ 
; V1.0 - Initial Release
; V1.1 - Relocate Menu For Gimp 2.6 - (update defaults) 
; V1.2 - Add Glass Effect Alpha - fluffybunny
; V1.3 - Modify Glass Effect Alpha - fluffybunny
;									Added Glass color input
;                                   Adjusted Shadow Offset X & Y min/max values to 50
;								    Changed default Shadow Color
;									as requested by dinasett (gimpchat.com) 
;
; User Options Popup
;
(script-fu-register "script-fu-glass-effect-text"
                    "<Image>/File/Create/Logos/Glass Effect Text..."
		    "Creates Glass-Effect Text with a drop shadow"
		    "Scott Mosteller"
		    "Scott Mosteller"
		    "2007"
		    ""
		    SF-STRING     _"Text"               "Gimp"
		    SF-ADJUSTMENT _"Font size (pixels)" '(150 2 1000 1 10 0 1)
		    SF-FONT       _"Font"               "Arial Black"
		    SF-COLOR      _"Text color"         '(123 149 176)
                    SF-PATTERN    _"Background Pattern" "Dried mud"
                    SF-ADJUSTMENT _"Glass Depth"        '(3 1 10 1 1 0 1)
                    SF-ADJUSTMENT _"Glass Translucency" '(64 0 255 1 1 0 1)
		    SF-COLOR      _"Shadow color"       '(0 0 0)
                    SF-ADJUSTMENT _"Shadow Offset X"    '(12 -25 25 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Offset Y"    '(12 -25 25 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Blur"        '(8 0 25 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Opacity"     '(60 0 100 1 1 0 1)
                    SF-TOGGLE     _"Include Shadow?"     TRUE
                    SF-TOGGLE     _"Include Background"  TRUE)

(script-fu-register "script-fu-glass-effect-alpha"
                    "<Image>/Filters/Alpha to Logo/Glass Effect Alpha..."
		    "Creates Glass-Effect of the Selection with a drop shadow"
		    "fluffybunny"
		    "fluffybunny"
		    "2013"
		    "RGBA"
					SF-IMAGE      "image"      0
					SF-DRAWABLE   "drawable"   0
					SF-COLOR	  _"Glass Color"		'(0 64 128)
					SF-ADJUSTMENT _"Glass Depth"        '(3 1 10 1 1 0 1)
                    SF-ADJUSTMENT _"Glass Translucency" '(64 0 255 1 1 0 1)
					SF-COLOR      _"Shadow color"       '(0 0 100)
                    SF-ADJUSTMENT _"Shadow Offset X"    '(12 -50 50 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Offset Y"    '(12 -50 50 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Blur"        '(8 0 25 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Opacity"     '(60 0 100 1 1 0 1)
                    SF-TOGGLE     _"Include Shadow?"     TRUE)
;
;
; Define Function For Glass Translucency Values
;
(define (get-glass-trans-curve parm)
  (let* ((curve-value (cons-array 4 'byte)))
   (aset curve-value 0 0)
   (aset curve-value 1 0)
   (aset curve-value 2 255)
   (aset curve-value 3 parm)
   curve-value     
   )
)
;
; Define RGB to HSV functions
;
(define (glass-text-do-rgb-to-hsv color)
	(let* (
			(r (car color))
			(g (cadr color))
			(b (caddr color))
			(cmin (min r (min g b)))
			(cmax (max r (max g b)))
			(diff 0.0)
			(rc 0.0)
			(gc 0.0)
			(bc 0.0)
			(h 0.0)
		  )
			
		(set! diff (- cmax cmin))
		(if (= diff 0.0)
			(set! diff (+ diff 1.0)))
		(set! rc (/ (- cmax r) diff))
		(set! gc (/ (- cmax g) diff))
		(set! bc (/ (- cmax b) diff))
		(set! h  (/ (if (= r cmax)
							(- bc gc)
							(if (= g cmax)
								(+ 2.0 (- rc bc))
								(+ 4.0 (- gc rc))))
						6.0))
		
		(list (if (= cmin cmax)
				0
				(* 360 (if (< h 0.0)
						(+ h 1.0)
						h
					)
				)
			)
			(if (= cmin cmax)
				0
				(/ (- cmax cmin) cmax)
			)
			cmax
		)
	)
)

; RGB to HSV in gimp ranges
(define (glass-text-conv-rgb-to-hsv color)
	(let*
		(
			(r (car color))
			(g (cadr color))
			(b (caddr color))
			(hsv (glass-text-do-rgb-to-hsv (list (/ r 255.0) (/ g 255.0) (/ b 255.0))))
			(h (car hsv))
			(s (cadr hsv))
			(v (caddr hsv))
		)
		(list h (* s 100.0) (* v 100.0))
	)
)

; Define Main Glass Text Function
;
(define (script-fu-glass-effect-text text
			       size
			       font
			       text-color
                               lpat
			       glass-depth
                               glass-trans
                +
				shadow-color
                               shx
                               shy
                               shb
                               sho
                               dsh
                               bkg)
  (let* ((img (car (gimp-image-new 256 256 RGB)))
    (tmp (car (gimp-context-set-foreground '( 255 255 255))))
    (text-layer2 (car (gimp-text-fontname img -1 0 0 text 10 TRUE (+ size shx) PIXELS font)))
    (text-layer3 (car (gimp-text-fontname img -1 0 0 text 10 TRUE size PIXELS font)))
    (tmp (car (gimp-context-set-foreground text-color)))
    (text-layer4 (car (gimp-text-fontname img -1 0 0 text 10 TRUE size PIXELS font)))
    (glass-layer)
    (trns)
    (spvalues (cons-array 4 'byte)))

;
; Glass Text Main Procedure Body
;
   (gimp-image-undo-disable img)
   (gimp-image-resize-to-layers img)
;
; Fill background
;
   (gimp-image-set-active-layer img text-layer2)
   (gimp-context-set-pattern lpat)
   (gimp-drawable-fill text-layer2 4)
   (gimp-drawable-set-name text-layer2 "Background")
   (gimp-layer-resize-to-image-size text-layer2)
;
; Create Glass Text 
;
;
   (gimp-image-set-active-layer img text-layer3)
   (gimp-layer-resize-to-image-size text-layer3)
   (gimp-selection-layer-alpha text-layer3)   
   (plug-in-gauss 1 img text-layer3 5 5 1)
   (gimp-drawable-set-visible text-layer3 0)

   (gimp-image-set-active-layer img text-layer4)
   (gimp-layer-resize-to-image-size text-layer4)
   (gimp-invert text-layer4)
   (plug-in-bump-map 1 img text-layer4 text-layer3 135 45 (+ glass-depth 0) 0 0 0 0 0 0 0)
   (gimp-selection-shrink img glass-depth)
   (gimp-selection-feather img (- glass-depth 1))

   (gimp-curves-spline text-layer4 4 4 (get-glass-trans-curve glass-trans))

   (set! glass-layer (car (gimp-layer-copy text-layer4 1)))
   (gimp-image-add-layer img glass-layer -1)

   (gimp-edit-clear text-layer4)
   (gimp-selection-none img)
   (gimp-hue-saturation text-layer4 0 0 0 -100)

   (gimp-invert glass-layer)
;
; Create shadow layer on request
;

  (if (= dsh TRUE)
   (begin
    (script-fu-drop-shadow img text-layer4 shx shy shb shadow-color sho TRUE)
   ))
;
; Clean up & delete layers as needed
;
  (gimp-image-remove-layer img text-layer3)
  (gimp-image-remove-layer img text-layer4)
  (gimp-image-set-active-layer img text-layer2)

  (if (= bkg FALSE)
   (begin
   (gimp-image-remove-layer img text-layer2)
   ))

   (gimp-selection-none img)
   (gimp-layer-resize-to-image-size glass-layer)
   (gimp-image-undo-enable img)
   (gimp-display-new img)))
;
; End Glass Text Main Procedure
;
;
; Define Main Glass Effect Alpha Function
;
(define (script-fu-glass-effect-alpha
		   image
		   drawable
		   glass-color
		   glass-depth
   		   glass-trans
		   shadow-color
		   shx
		   shy
		   shb
		   sho
		   dsh
		)
	(gimp-context-push)
	(gimp-image-undo-group-start image)						  

	(let* (
            (active-layer (car (gimp-image-get-active-layer image)))
		    (sel (car (gimp-selection-is-empty image)))
			(width (car (gimp-image-width image)))
			(height (car (gimp-image-height image)))
			(Layer-Mode (car (gimp-layer-get-mode active-layer)))
			(Layer-Opacity (car (gimp-layer-get-opacity active-layer)))
			(Layer-Type (car (gimp-drawable-type active-layer)))
			(layer-blur)
			(layer-bump)
			(layer-glass)
			(floating-selection)
			(hsv 0)
			(h 0)
			(s 0)
			(v 0)
		   )

; Glass Alpha Main Procedure Body
	(gimp-context-set-default-colors)
;;;;check that a selection was made if not make one	
	(if (= sel TRUE) (gimp-selection-layer-alpha active-layer))
	(gimp-edit-copy active-layer)

    (set! layer-blur (car (gimp-layer-new image width height Layer-Type "Blur" Layer-Opacity Layer-Mode)))
	(gimp-image-add-layer image layer-blur -1)

	(set! floating-selection (car (gimp-edit-paste layer-blur TRUE)))
	(gimp-floating-sel-anchor floating-selection)

	(set! layer-bump (car (gimp-layer-copy layer-blur TRUE)))
	(gimp-image-add-layer image layer-bump -1)
	(gimp-layer-set-name layer-bump "Bump")
	(gimp-drawable-set-visible active-layer FALSE)
	
   (gimp-image-set-active-layer image layer-blur)
   (gimp-layer-resize-to-image-size layer-blur)
   (gimp-selection-layer-alpha layer-blur)   
   (plug-in-gauss 1 image layer-blur 5 5 1)
   (gimp-drawable-set-visible layer-blur FALSE)

   (gimp-image-set-active-layer image layer-bump)
   (gimp-layer-resize-to-image-size layer-bump)
   (gimp-invert layer-bump)
   (plug-in-bump-map 1 image layer-bump layer-blur 135 45 (+ glass-depth 0) 0 0 0 0 0 0 0)
   (gimp-selection-shrink image glass-depth)
   (gimp-selection-feather image (- glass-depth 1))

   (gimp-curves-spline layer-bump 4 4 (get-glass-trans-curve glass-trans))

   (set! layer-glass (car (gimp-layer-copy layer-bump 1)))
   (gimp-image-add-layer image layer-glass -1)
   (gimp-layer-set-name layer-glass "Glass")


   (gimp-edit-clear layer-bump)
   (gimp-selection-none image)
   (gimp-hue-saturation layer-bump 0 0 0 -100)

   (gimp-invert layer-glass)
;
; Create shadow layer on request
;
  (if (= dsh TRUE)
    (script-fu-drop-shadow image layer-bump shx shy shb shadow-color sho TRUE))
;
; Glass color
;
	(set! hsv (glass-text-conv-rgb-to-hsv glass-color))
	(set! h (car hsv))
	(set! s (cadr hsv))
	(set! v (caddr hsv))
	(set! v (- v 100))
;(gimp-message (string-append "HSV " (number->string h) " " (number->string s) " " (number->string v)))
	(gimp-colorize layer-glass h s v)
;
; Clean up & delete layers as needed
;
   (gimp-layer-resize-to-image-size layer-glass)
   (gimp-image-remove-layer image layer-blur)
   (gimp-image-remove-layer image layer-bump)
 
   (gimp-selection-none image)
   (gimp-image-set-active-layer image layer-glass)
   (gimp-displays-flush)
   (gimp-image-undo-group-end image)
   (gimp-context-pop)
)
)
;
; End Glass Alpha Main Procedure
;
